package org.code_blue.dmxcremote.v2;

import org.code_blue.dmxcremote.v2.classes.DMXConnection;
import org.code_blue.dmxcremote.v2.classes.TCPConnection;


import android.app.Activity;
import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.content.SharedPreferences;
import android.content.pm.ActivityInfo;
import android.os.Bundle;
import android.os.Message;
import android.util.Log;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.view.Window;
import android.widget.ProgressBar;
import android.widget.TextView;

public class ConnectionScreen extends Activity {
    private DMXConnection conn;
	private ConnectionFailed cFailedReceiver=new ConnectionFailed();
	private ConnectionOK cOKReceiver=new ConnectionOK();
    
    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setRequestedOrientation(ActivityInfo.SCREEN_ORIENTATION_PORTRAIT);
        requestWindowFeature(Window.FEATURE_NO_TITLE);
        Log.d("DMX","connection oncreate");
        conn=((RemoteApp)getApplication()).getDMXConnection();
        setContentView(R.layout.connect);
    }
    
    @Override
    protected void onResume(){
    	super.onResume();
    	Log.d("DMX","onResume: registering bc receivers");
        registerReceiver(cFailedReceiver,new IntentFilter("org.code_blue.dmxcremote.v2.CONNECTIONFAILED"));
        registerReceiver(cOKReceiver,new IntentFilter("org.code_blue.dmxcremote.v2.CONNECTED"));
        if(!conn.isReady()){
        	Log.d("DMX","starting from home, -> init");
        	//startConnection();
        }
        else{
        	Log.d("DMX","connection is active, -> exit");
        	finish();
        }
    }
    
    @Override
    protected void onPause(){
    	super.onPause();
    	Log.d("DMX","onPause: unregistering bc receivers");
    	unregisterReceiver(cFailedReceiver);
    	unregisterReceiver(cOKReceiver);
    }
    
    @Override
    protected void onDestroy(){
    	super.onDestroy();
    	if(isFinishing()){
    		conn.stop();
    		Message m=((RemoteApp)getApplication()).getApplicationHandler().obtainMessage(0,RemoteApp.HANDLE.DISPLAYTOAST);
    		m.getData().putString("message","Connection closed");
    		m.sendToTarget();
    	}
    }
    
	@Override
	public boolean onCreateOptionsMenu(Menu menu) {
		menu.add(Menu.NONE,1,Menu.NONE,"Configure");
		menu.add(Menu.NONE,2,Menu.NONE,"Connect");
		return true;
	}
	
	@Override
	public boolean onOptionsItemSelected(MenuItem item) {
	    switch (item.getItemId()) {
	    case 1:
	    	runSetup();
	        return true;
	    case 2:
	    	conn.stop();
	    	startConnection();
	    	return true;
	    default:
	        return super.onOptionsItemSelected(item);
	    }
	}
	
	public void startConnection(){
		((TextView)findViewById(R.id.connectingText)).setText("Connecting...");
		((ProgressBar)findViewById(R.id.connectProgress)).setVisibility(View.VISIBLE);
		
    	SharedPreferences preferences=getSharedPreferences("DMXRemotev2",MODE_PRIVATE);
    	String serverAddress=preferences.getString("serverAddress","localhost");
    	int serverPort=preferences.getInt("serverPort",2145);
        
    	((TCPConnection)conn).setupConnection(serverAddress,serverPort);
    	conn.start();
	}
	
	public void runSetup(){
        startActivity(new Intent(getApplicationContext(),SetupActivity.class));
	}
    
    public void showAbout(View v){
    	startActivity(new Intent(getApplicationContext(),AboutActivity.class));
    }
    
    private class ConnectionOK extends BroadcastReceiver{
		@Override
		public void onReceive(Context arg0, Intent arg1) {
			Log.d("DMX","received broadcast: conn ok");
			((TextView)findViewById(R.id.connectingText)).setText("OK");
			((ProgressBar)findViewById(R.id.connectProgress)).setVisibility(View.INVISIBLE);
			startActivity(new Intent(getApplicationContext(),TabHost.class));
		}
    }
    
    private class ConnectionFailed extends BroadcastReceiver{
		@Override
		public void onReceive(Context context, Intent intent) {
			Log.d("DMX","received broadcast: conn failed");
			((TextView)findViewById(R.id.connectingText)).setText("Failed to connect");
			((ProgressBar)findViewById(R.id.connectProgress)).setVisibility(View.INVISIBLE);
		}
    }
}